@@ -113,7 +113,7 @@ public class KinCanvas extends JComponent implements KMessage.Subscriber, Transf
         
         engine = new Engine2D();
         updatePrefs(engine, props);
-        logo = Toolkit.getDefaultToolkit().getImage(this.getClass().getResource("images/king-logo.gif"));
+        logo = Toolkit.getDefaultToolkit().getImage(this.getClass().getResource("images/king-logo.2016.png"));
         
         toolbox = new ToolBox(kMain, this);
         toolbox.listenTo(this);
@@ -235,7 +235,7 @@ public class KinCanvas extends JComponent implements KMessage.Subscriber, Transf
             joglAction.actionPerformed(null);
         else
         {
-            Painter painter = null;
+            king.core.Painter painter = null;
             if(quality == QUALITY_BETTER)
             {
                 betterPainter.setGraphics(g2);
